<?php

namespace Drupal\webform_protected_downloads;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class WebformProtectedDownloadsManager.
 *
 * @package Drupal\webform_protected_downloads
 */
class WebformProtectedDownloadsManager implements WebformProtectedDownloadsManagerInterface, ContainerInjectionInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a GroupContentCardinalityValidator object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getSubmissionByUuid($uuid, $handler_id = NULL) {
    $storage = $this->entityTypeManager->getStorage('webform_protected_downloads');
    $query = $storage->getQuery()
      ->accessCheck(TRUE)
      ->condition('webform_submission.entity.uuid', $uuid);
    if (isset($handler_id) && strlen($handler_id)) {
      $query->condition('handler_id', $handler_id);
    }

    foreach ($storage->loadMultiple($query->execute()) as $entity) {
      if ($entity->getHandler()) {
        // Return WebformProtectedDownload.
        return $entity;
      }
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getSubmissionByHash($hash) {
    $storage = $this->entityTypeManager->getStorage('webform_protected_downloads');
    $result = $storage->getQuery()
      ->accessCheck(TRUE)
      ->condition('hash', $hash)
      ->execute();

    // Return entity if exists or FALSE.
    if ($result) {
      return $storage->load(reset($result));
    }
    else {
      return FALSE;
    }
  }

}
